@@ -15,16 +15,11 @@ import subprocess
 import time
 import urllib2
 
-VERSION = (0, 0, 4, 'final')
-
-assert(VERSION[3] in ('dev', 'final'))
+VERSION = (0, 1, 0)
 
 
 def get_version():
-    ret = '%d.%d.%d' % (VERSION[0], VERSION[1], VERSION[2])
-    if VERSION[3] == 'dev':
-        ret += '-dev'
-    return ret
+    return '%d.%d.%d' % (VERSION[0], VERSION[1], VERSION[2])
 
 
 class WebDriver(WebDriverMixin):
@@ -117,7 +112,7 @@ class HtmlUnit(WebDriverMixin, _Remote):
 
     def __init__(self, *args, **kwargs):
         self._perform_auto_install()
-        #self._autorun_selenium_server()
+        self._autorun_selenium_server()
         super(HtmlUnit, self).__init__("http://localhost:4444/wd/hub",
                                        DesiredCapabilities.HTMLUNIT, **kwargs)
 
